
:autogenerated:

krotov.functionals module
=========================

.. currentmodule:: krotov.functionals

.. automodule:: krotov.functionals
    :members: F_avg, F_re, F_sm, F_ss, J_T_hs, J_T_re, J_T_sm, J_T_ss, chis_hs, chis_re, chis_sm, chis_ss, f_tau, gate, mapped_basis
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Functions:

    .. autosummary::
        :nosignatures:

        F_avg
        F_re
        F_sm
        F_ss
        J_T_hs
        J_T_re
        J_T_sm
        J_T_ss
        chis_hs
        chis_re
        chis_sm
        chis_ss
        f_tau
        gate
        mapped_basis





    ``__all__``: :func:`F_avg <krotov.functionals.F_avg>`, :func:`F_re <krotov.functionals.F_re>`, :func:`F_sm <krotov.functionals.F_sm>`, :func:`F_ss <krotov.functionals.F_ss>`, :func:`J_T_hs <krotov.functionals.J_T_hs>`, :func:`J_T_re <krotov.functionals.J_T_re>`, :func:`J_T_sm <krotov.functionals.J_T_sm>`, :func:`J_T_ss <krotov.functionals.J_T_ss>`, :func:`chis_hs <krotov.functionals.chis_hs>`, :func:`chis_re <krotov.functionals.chis_re>`, :func:`chis_sm <krotov.functionals.chis_sm>`, :func:`chis_ss <krotov.functionals.chis_ss>`, :func:`f_tau <krotov.functionals.f_tau>`, :func:`gate <krotov.functionals.gate>`, :func:`mapped_basis <krotov.functionals.mapped_basis>`



    Reference
    ---------